==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterListenerMatchFilterChainMatchBuilder extends EnvoyFilterListenerMatchFilterChainMatchFluent<EnvoyFilterListenerMatchFilterChainMatchBuilder> implements VisitableBuilder<EnvoyFilterListenerMatchFilterChainMatch,EnvoyFilterListenerMatchFilterChainMatchBuilder>{
  public EnvoyFilterListenerMatchFilterChainMatchBuilder() {
    this(false);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterListenerMatchFilterChainMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterListenerMatchFilterChainMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent,EnvoyFilterListenerMatchFilterChainMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent,EnvoyFilterListenerMatchFilterChainMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchFilterChainMatch());

    if (instance != null) {
      fluent.withApplicationProtocols(instance.getApplicationProtocols());
      fluent.withDestinationPort(instance.getDestinationPort());
      fluent.withFilter(instance.getFilter());
      fluent.withName(instance.getName());
      fluent.withSni(instance.getSni());
      fluent.withTransportProtocol(instance.getTransportProtocol());
      fluent.withApplicationProtocols(instance.getApplicationProtocols());
      fluent.withDestinationPort(instance.getDestinationPort());
      fluent.withFilter(instance.getFilter());
      fluent.withName(instance.getName());
      fluent.withSni(instance.getSni());
      fluent.withTransportProtocol(instance.getTransportProtocol());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchFilterChainMatch());

    if (instance != null) {
      this.withApplicationProtocols(instance.getApplicationProtocols());
      this.withDestinationPort(instance.getDestinationPort());
      this.withFilter(instance.getFilter());
      this.withName(instance.getName());
      this.withSni(instance.getSni());
      this.withTransportProtocol(instance.getTransportProtocol());
      this.withApplicationProtocols(instance.getApplicationProtocols());
      this.withDestinationPort(instance.getDestinationPort());
      this.withFilter(instance.getFilter());
      this.withName(instance.getName());
      this.withSni(instance.getSni());
      this.withTransportProtocol(instance.getTransportProtocol());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterListenerMatchFilterChainMatch build() {
    EnvoyFilterListenerMatchFilterChainMatch buildable = new EnvoyFilterListenerMatchFilterChainMatch(fluent.getApplicationProtocols(),fluent.getDestinationPort(),fluent.buildFilter(),fluent.getName(),fluent.getSni(),fluent.getTransportProtocol());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class EnvoyFilterListenerMatchFilterChainMatchBuilder extends EnvoyFilterListenerMatchFilterChainMatchFluent<EnvoyFilterListenerMatchFilterChainMatchBuilder> implements VisitableBuilder<EnvoyFilterListenerMatchFilterChainMatch,EnvoyFilterListenerMatchFilterChainMatchBuilder>{
  public EnvoyFilterListenerMatchFilterChainMatchBuilder() {
    this(new EnvoyFilterListenerMatchFilterChainMatch());
  }
  
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent) {
    this(fluent, new EnvoyFilterListenerMatchFilterChainMatch());
  }
  
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent,EnvoyFilterListenerMatchFilterChainMatch instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public EnvoyFilterListenerMatchFilterChainMatchBuilder(EnvoyFilterListenerMatchFilterChainMatch instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  EnvoyFilterListenerMatchFilterChainMatchFluent<?> fluent;
  
  public EnvoyFilterListenerMatchFilterChainMatch build() {
    EnvoyFilterListenerMatchFilterChainMatch buildable = new EnvoyFilterListenerMatchFilterChainMatch(fluent.getApplicationProtocols(),fluent.getDestinationPort(),fluent.buildFilter(),fluent.getName(),fluent.getSni(),fluent.getTransportProtocol());
    return buildable;
  }
  

}
